# coding: utf-8
#
# Copyright 2022 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Interface Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.3
# Namespace: com.sun.star.table
import typing
from abc import abstractmethod
from ..container.x_name_access import XNameAccess as XNameAccess_e2ab0cf6
if typing.TYPE_CHECKING:
    from ..awt.rectangle import Rectangle as Rectangle_84b109e9

class XTablePivotCharts(XNameAccess_e2ab0cf6):
    """
    provides methods to access pivot charts via name and to insert and remove pivot charts.
    
    **since**
    
        LibreOffice 5.4

    See Also:
        `API XTablePivotCharts <https://api.libreoffice.org/docs/idl/ref/interfacecom_1_1sun_1_1star_1_1table_1_1XTablePivotCharts.html>`_
    """
    __ooo_ns__: str = 'com.sun.star.table'
    __ooo_full_ns__: str = 'com.sun.star.table.XTablePivotCharts'
    __ooo_type_name__: str = 'interface'
    __pyunointerface__: str = 'com.sun.star.table.XTablePivotCharts'

    @abstractmethod
    def addNewByName(self, aName: str, aRect: 'Rectangle_84b109e9', aPivotTableName: str) -> None:
        """
        creates a pivot chart and adds it to the collection.
        """
    @abstractmethod
    def removeByName(self, aName: str) -> None:
        """
        removes a pivot chart from the collection.
        """

__all__ = ['XTablePivotCharts']

