# coding: utf-8
#
# Copyright 2022 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
from ...dyn.drawing.accessible_draw_document_view import AccessibleDrawDocumentView as AccessibleDrawDocumentView
from ...dyn.drawing.accessible_graph_control import AccessibleGraphControl as AccessibleGraphControl
from ...dyn.drawing.accessible_graphic_shape import AccessibleGraphicShape as AccessibleGraphicShape
from ...dyn.drawing.accessible_image_bullet import AccessibleImageBullet as AccessibleImageBullet
from ...dyn.drawing.accessible_ole_shape import AccessibleOLEShape as AccessibleOLEShape
from ...dyn.drawing.accessible_shape import AccessibleShape as AccessibleShape
from ...dyn.drawing.accessible_slide_view import AccessibleSlideView as AccessibleSlideView
from ...dyn.drawing.accessible_slide_view_object import AccessibleSlideViewObject as AccessibleSlideViewObject
from ...dyn.drawing.alignment import Alignment as Alignment
from ...dyn.drawing.applet_shape import AppletShape as AppletShape
from ...dyn.drawing.arrangement import Arrangement as Arrangement
from ...dyn.drawing.background import Background as Background
from ...dyn.drawing.bar_code import BarCode as BarCode
from ...dyn.drawing.bar_code_error_correction import BarCodeErrorCorrection as BarCodeErrorCorrection
from ...dyn.drawing.bar_code_error_correction import BarCodeErrorCorrectionEnum as BarCodeErrorCorrectionEnum
from ...dyn.drawing.bezier_point import BezierPoint as BezierPoint
from ...dyn.drawing.bitmap_mode import BitmapMode as BitmapMode
from ...dyn.drawing.bitmap_table import BitmapTable as BitmapTable
from ...dyn.drawing.bound_volume import BoundVolume as BoundVolume
from ...dyn.drawing.camera_geometry import CameraGeometry as CameraGeometry
from ...dyn.drawing.canvas_feature import CanvasFeature as CanvasFeature
from ...dyn.drawing.canvas_feature import CanvasFeatureEnum as CanvasFeatureEnum
from ...dyn.drawing.caption_escape_direction import CaptionEscapeDirection as CaptionEscapeDirection
from ...dyn.drawing.caption_escape_direction import CaptionEscapeDirectionEnum as CaptionEscapeDirectionEnum
from ...dyn.drawing.caption_shape import CaptionShape as CaptionShape
from ...dyn.drawing.caption_type import CaptionType as CaptionType
from ...dyn.drawing.caption_type import CaptionTypeEnum as CaptionTypeEnum
from ...dyn.drawing.circle_kind import CircleKind as CircleKind
from ...dyn.drawing.closed_bezier_shape import ClosedBezierShape as ClosedBezierShape
from ...dyn.drawing.color_mode import ColorMode as ColorMode
from ...dyn.drawing.color_table import ColorTable as ColorTable
from ...dyn.drawing.connection_type import ConnectionType as ConnectionType
from ...dyn.drawing.connector_properties import ConnectorProperties as ConnectorProperties
from ...dyn.drawing.connector_shape import ConnectorShape as ConnectorShape
from ...dyn.drawing.connector_type import ConnectorType as ConnectorType
from ...dyn.drawing.control_shape import ControlShape as ControlShape
from ...dyn.drawing.coordinate_sequence import CoordinateSequence as CoordinateSequence
from ...dyn.drawing.coordinate_sequence_sequence import CoordinateSequenceSequence as CoordinateSequenceSequence
from ...dyn.drawing.custom_shape import CustomShape as CustomShape
from ...dyn.drawing.custom_shape_engine import CustomShapeEngine as CustomShapeEngine
from ...dyn.drawing.dash_style import DashStyle as DashStyle
from ...dyn.drawing.dash_table import DashTable as DashTable
from ...dyn.drawing.defaults import Defaults as Defaults
from ...dyn.drawing.direction3_d import Direction3D as Direction3D
from ...dyn.drawing.document_settings import DocumentSettings as DocumentSettings
from ...dyn.drawing.double_sequence import DoubleSequence as DoubleSequence
from ...dyn.drawing.double_sequence_sequence import DoubleSequenceSequence as DoubleSequenceSequence
from ...dyn.drawing.draw_page import DrawPage as DrawPage
from ...dyn.drawing.draw_pages import DrawPages as DrawPages
from ...dyn.drawing.draw_view_mode import DrawViewMode as DrawViewMode
from ...dyn.drawing.drawing_document import DrawingDocument as DrawingDocument
from ...dyn.drawing.drawing_document_draw_view import DrawingDocumentDrawView as DrawingDocumentDrawView
from ...dyn.drawing.drawing_document_factory import DrawingDocumentFactory as DrawingDocumentFactory
from ...dyn.drawing.ellipse_shape import EllipseShape as EllipseShape
from ...dyn.drawing.enhanced_custom_shape_adjustment_value import EnhancedCustomShapeAdjustmentValue as EnhancedCustomShapeAdjustmentValue
from ...dyn.drawing.enhanced_custom_shape_extrusion import EnhancedCustomShapeExtrusion as EnhancedCustomShapeExtrusion
from ...dyn.drawing.enhanced_custom_shape_geometry import EnhancedCustomShapeGeometry as EnhancedCustomShapeGeometry
from ...dyn.drawing.enhanced_custom_shape_glue_point_type import EnhancedCustomShapeGluePointType as EnhancedCustomShapeGluePointType
from ...dyn.drawing.enhanced_custom_shape_glue_point_type import EnhancedCustomShapeGluePointTypeEnum as EnhancedCustomShapeGluePointTypeEnum
from ...dyn.drawing.enhanced_custom_shape_handle import EnhancedCustomShapeHandle as EnhancedCustomShapeHandle
from ...dyn.drawing.enhanced_custom_shape_parameter import EnhancedCustomShapeParameter as EnhancedCustomShapeParameter
from ...dyn.drawing.enhanced_custom_shape_parameter_pair import EnhancedCustomShapeParameterPair as EnhancedCustomShapeParameterPair
from ...dyn.drawing.enhanced_custom_shape_parameter_type import EnhancedCustomShapeParameterType as EnhancedCustomShapeParameterType
from ...dyn.drawing.enhanced_custom_shape_parameter_type import EnhancedCustomShapeParameterTypeEnum as EnhancedCustomShapeParameterTypeEnum
from ...dyn.drawing.enhanced_custom_shape_path import EnhancedCustomShapePath as EnhancedCustomShapePath
from ...dyn.drawing.enhanced_custom_shape_segment import EnhancedCustomShapeSegment as EnhancedCustomShapeSegment
from ...dyn.drawing.enhanced_custom_shape_segment_command import EnhancedCustomShapeSegmentCommand as EnhancedCustomShapeSegmentCommand
from ...dyn.drawing.enhanced_custom_shape_segment_command import EnhancedCustomShapeSegmentCommandEnum as EnhancedCustomShapeSegmentCommandEnum
from ...dyn.drawing.enhanced_custom_shape_text_frame import EnhancedCustomShapeTextFrame as EnhancedCustomShapeTextFrame
from ...dyn.drawing.enhanced_custom_shape_text_path import EnhancedCustomShapeTextPath as EnhancedCustomShapeTextPath
from ...dyn.drawing.enhanced_custom_shape_text_path_mode import EnhancedCustomShapeTextPathMode as EnhancedCustomShapeTextPathMode
from ...dyn.drawing.escape_direction import EscapeDirection as EscapeDirection
from ...dyn.drawing.fill_properties import FillProperties as FillProperties
from ...dyn.drawing.fill_style import FillStyle as FillStyle
from ...dyn.drawing.flag_sequence import FlagSequence as FlagSequence
from ...dyn.drawing.flag_sequence_sequence import FlagSequenceSequence as FlagSequenceSequence
from ...dyn.drawing.generic_draw_page import GenericDrawPage as GenericDrawPage
from ...dyn.drawing.generic_drawing_document import GenericDrawingDocument as GenericDrawingDocument
from ...dyn.drawing.glue_point import GluePoint as GluePoint
from ...dyn.drawing.glue_point2 import GluePoint2 as GluePoint2
from ...dyn.drawing.gradient_table import GradientTable as GradientTable
from ...dyn.drawing.graphic_export_filter import GraphicExportFilter as GraphicExportFilter
from ...dyn.drawing.graphic_filter_request import GraphicFilterRequest as GraphicFilterRequest
from ...dyn.drawing.graphic_object_shape import GraphicObjectShape as GraphicObjectShape
from ...dyn.drawing.group_shape import GroupShape as GroupShape
from ...dyn.drawing.hatch import Hatch as Hatch
from ...dyn.drawing.hatch_style import HatchStyle as HatchStyle
from ...dyn.drawing.hatch_table import HatchTable as HatchTable
from ...dyn.drawing.homogen_matrix import HomogenMatrix as HomogenMatrix
from ...dyn.drawing.homogen_matrix3 import HomogenMatrix3 as HomogenMatrix3
from ...dyn.drawing.homogen_matrix4 import HomogenMatrix4 as HomogenMatrix4
from ...dyn.drawing.homogen_matrix_line import HomogenMatrixLine as HomogenMatrixLine
from ...dyn.drawing.homogen_matrix_line3 import HomogenMatrixLine3 as HomogenMatrixLine3
from ...dyn.drawing.homogen_matrix_line4 import HomogenMatrixLine4 as HomogenMatrixLine4
from ...dyn.drawing.horizontal_dimensioning import HorizontalDimensioning as HorizontalDimensioning
from ...dyn.drawing.layer import Layer as Layer
from ...dyn.drawing.layer_manager import LayerManager as LayerManager
from ...dyn.drawing.layer_type import LayerType as LayerType
from ...dyn.drawing.line_cap import LineCap as LineCap
from ...dyn.drawing.line_dash import LineDash as LineDash
from ...dyn.drawing.line_end_type import LineEndType as LineEndType
from ...dyn.drawing.line_joint import LineJoint as LineJoint
from ...dyn.drawing.line_properties import LineProperties as LineProperties
from ...dyn.drawing.line_shape import LineShape as LineShape
from ...dyn.drawing.line_style import LineStyle as LineStyle
from ...dyn.drawing.marker_table import MarkerTable as MarkerTable
from ...dyn.drawing.master_page import MasterPage as MasterPage
from ...dyn.drawing.master_pages import MasterPages as MasterPages
from ...dyn.drawing.measure_kind import MeasureKind as MeasureKind
from ...dyn.drawing.measure_properties import MeasureProperties as MeasureProperties
from ...dyn.drawing.measure_shape import MeasureShape as MeasureShape
from ...dyn.drawing.measure_text_horz_pos import MeasureTextHorzPos as MeasureTextHorzPos
from ...dyn.drawing.measure_text_vert_pos import MeasureTextVertPos as MeasureTextVertPos
from ...dyn.drawing.mirror_axis import MirrorAxis as MirrorAxis
from ...dyn.drawing.module_dispatcher import ModuleDispatcher as ModuleDispatcher
from ...dyn.drawing.normals_kind import NormalsKind as NormalsKind
from ...dyn.drawing.ole2_shape import OLE2Shape as OLE2Shape
from ...dyn.drawing.open_bezier_shape import OpenBezierShape as OpenBezierShape
from ...dyn.drawing.page_shape import PageShape as PageShape
from ...dyn.drawing.plugin_shape import PluginShape as PluginShape
from ...dyn.drawing.point_sequence import PointSequence as PointSequence
from ...dyn.drawing.point_sequence_sequence import PointSequenceSequence as PointSequenceSequence
from ...dyn.drawing.poly_line_shape import PolyLineShape as PolyLineShape
from ...dyn.drawing.poly_polygon_bezier_coords import PolyPolygonBezierCoords as PolyPolygonBezierCoords
from ...dyn.drawing.poly_polygon_bezier_descriptor import PolyPolygonBezierDescriptor as PolyPolygonBezierDescriptor
from ...dyn.drawing.poly_polygon_bezier_shape import PolyPolygonBezierShape as PolyPolygonBezierShape
from ...dyn.drawing.poly_polygon_descriptor import PolyPolygonDescriptor as PolyPolygonDescriptor
from ...dyn.drawing.poly_polygon_shape import PolyPolygonShape as PolyPolygonShape
from ...dyn.drawing.poly_polygon_shape3_d import PolyPolygonShape3D as PolyPolygonShape3D
from ...dyn.drawing.polygon_flags import PolygonFlags as PolygonFlags
from ...dyn.drawing.polygon_kind import PolygonKind as PolygonKind
from ...dyn.drawing.position3_d import Position3D as Position3D
from ...dyn.drawing.projection_mode import ProjectionMode as ProjectionMode
from ...dyn.drawing.rectangle_point import RectanglePoint as RectanglePoint
from ...dyn.drawing.rectangle_shape import RectangleShape as RectangleShape
from ...dyn.drawing.rotation_descriptor import RotationDescriptor as RotationDescriptor
from ...dyn.drawing.shade_mode import ShadeMode as ShadeMode
from ...dyn.drawing.shading_pattern import ShadingPattern as ShadingPattern
from ...dyn.drawing.shading_pattern import ShadingPatternEnum as ShadingPatternEnum
from ...dyn.drawing.shadow_properties import ShadowProperties as ShadowProperties
from ...dyn.drawing.shape import Shape as Shape
from ...dyn.drawing.shape_collection import ShapeCollection as ShapeCollection
from ...dyn.drawing.shapes import Shapes as Shapes
from ...dyn.drawing.slide_renderer import SlideRenderer as SlideRenderer
from ...dyn.drawing.slide_sorter import SlideSorter as SlideSorter
from ...dyn.drawing.snap_object_type import SnapObjectType as SnapObjectType
from ...dyn.drawing.text import Text as Text
from ...dyn.drawing.text_adjust import TextAdjust as TextAdjust
from ...dyn.drawing.text_animation_direction import TextAnimationDirection as TextAnimationDirection
from ...dyn.drawing.text_animation_kind import TextAnimationKind as TextAnimationKind
from ...dyn.drawing.text_fit_to_size_type import TextFitToSizeType as TextFitToSizeType
from ...dyn.drawing.text_horizontal_adjust import TextHorizontalAdjust as TextHorizontalAdjust
from ...dyn.drawing.text_properties import TextProperties as TextProperties
from ...dyn.drawing.text_shape import TextShape as TextShape
from ...dyn.drawing.text_vertical_adjust import TextVerticalAdjust as TextVerticalAdjust
from ...dyn.drawing.texture_kind import TextureKind as TextureKind
from ...dyn.drawing.texture_kind2 import TextureKind2 as TextureKind2
from ...dyn.drawing.texture_mode import TextureMode as TextureMode
from ...dyn.drawing.texture_projection_mode import TextureProjectionMode as TextureProjectionMode
from ...dyn.drawing.transparency_gradient_table import TransparencyGradientTable as TransparencyGradientTable
from ...dyn.drawing.vertical_dimensioning import VerticalDimensioning as VerticalDimensioning
from ...dyn.drawing.x_connectable_shape import XConnectableShape as XConnectableShape
from ...dyn.drawing.x_connector_shape import XConnectorShape as XConnectorShape
from ...dyn.drawing.x_control_shape import XControlShape as XControlShape
from ...dyn.drawing.x_custom_shape_engine import XCustomShapeEngine as XCustomShapeEngine
from ...dyn.drawing.x_custom_shape_handle import XCustomShapeHandle as XCustomShapeHandle
from ...dyn.drawing.x_draw_page import XDrawPage as XDrawPage
from ...dyn.drawing.x_draw_page_duplicator import XDrawPageDuplicator as XDrawPageDuplicator
from ...dyn.drawing.x_draw_page_expander import XDrawPageExpander as XDrawPageExpander
from ...dyn.drawing.x_draw_page_summarizer import XDrawPageSummarizer as XDrawPageSummarizer
from ...dyn.drawing.x_draw_page_supplier import XDrawPageSupplier as XDrawPageSupplier
from ...dyn.drawing.x_draw_pages import XDrawPages as XDrawPages
from ...dyn.drawing.x_draw_pages_supplier import XDrawPagesSupplier as XDrawPagesSupplier
from ...dyn.drawing.x_draw_sub_controller import XDrawSubController as XDrawSubController
from ...dyn.drawing.x_draw_view import XDrawView as XDrawView
from ...dyn.drawing.x_enhanced_custom_shape_defaulter import XEnhancedCustomShapeDefaulter as XEnhancedCustomShapeDefaulter
from ...dyn.drawing.x_glue_points_supplier import XGluePointsSupplier as XGluePointsSupplier
from ...dyn.drawing.x_graphic_export_filter import XGraphicExportFilter as XGraphicExportFilter
from ...dyn.drawing.x_layer import XLayer as XLayer
from ...dyn.drawing.x_layer_manager import XLayerManager as XLayerManager
from ...dyn.drawing.x_layer_supplier import XLayerSupplier as XLayerSupplier
from ...dyn.drawing.x_master_page_target import XMasterPageTarget as XMasterPageTarget
from ...dyn.drawing.x_master_pages_supplier import XMasterPagesSupplier as XMasterPagesSupplier
from ...dyn.drawing.x_presenter_helper import XPresenterHelper as XPresenterHelper
from ...dyn.drawing.x_selection_function import XSelectionFunction as XSelectionFunction
from ...dyn.drawing.x_shape import XShape as XShape
from ...dyn.drawing.x_shape_aligner import XShapeAligner as XShapeAligner
from ...dyn.drawing.x_shape_arranger import XShapeArranger as XShapeArranger
from ...dyn.drawing.x_shape_binder import XShapeBinder as XShapeBinder
from ...dyn.drawing.x_shape_combiner import XShapeCombiner as XShapeCombiner
from ...dyn.drawing.x_shape_descriptor import XShapeDescriptor as XShapeDescriptor
from ...dyn.drawing.x_shape_group import XShapeGroup as XShapeGroup
from ...dyn.drawing.x_shape_grouper import XShapeGrouper as XShapeGrouper
from ...dyn.drawing.x_shape_mirror import XShapeMirror as XShapeMirror
from ...dyn.drawing.x_shapes import XShapes as XShapes
from ...dyn.drawing.x_shapes2 import XShapes2 as XShapes2
from ...dyn.drawing.x_shapes3 import XShapes3 as XShapes3
from ...dyn.drawing.x_slide_preview_cache import XSlidePreviewCache as XSlidePreviewCache
from ...dyn.drawing.x_slide_preview_cache_listener import XSlidePreviewCacheListener as XSlidePreviewCacheListener
from ...dyn.drawing.x_slide_renderer import XSlideRenderer as XSlideRenderer
from ...dyn.drawing.x_slide_sorter_base import XSlideSorterBase as XSlideSorterBase
from ...dyn.drawing.x_universal_shape_descriptor import XUniversalShapeDescriptor as XUniversalShapeDescriptor
