# coding: utf-8
#
# Copyright 2022 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Interface Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.3
# Namespace: com.sun.star.drawing
import typing
from abc import abstractmethod
from ..uno.x_interface import XInterface as XInterface_8f010a43
if typing.TYPE_CHECKING:
    from ..awt.rectangle import Rectangle as Rectangle_84b109e9
    from .poly_polygon_bezier_coords import PolyPolygonBezierCoords as PolyPolygonBezierCoords_7ec5114b
    from .x_custom_shape_handle import XCustomShapeHandle as XCustomShapeHandle_2a620f04
    from .x_shape import XShape as XShape_8fd00a3d

class XCustomShapeEngine(XInterface_8f010a43):
    """
    The XCustomShapeEngine.

    See Also:
        `API XCustomShapeEngine <https://api.libreoffice.org/docs/idl/ref/interfacecom_1_1sun_1_1star_1_1drawing_1_1XCustomShapeEngine.html>`_
    """
    __ooo_ns__: str = 'com.sun.star.drawing'
    __ooo_full_ns__: str = 'com.sun.star.drawing.XCustomShapeEngine'
    __ooo_type_name__: str = 'interface'
    __pyunointerface__: str = 'com.sun.star.drawing.XCustomShapeEngine'

    @abstractmethod
    def getInteraction(self) -> 'typing.Tuple[XCustomShapeHandle_2a620f04, ...]':
        """
        """
    @abstractmethod
    def getLineGeometry(self) -> 'PolyPolygonBezierCoords_7ec5114b':
        """
        """
    @abstractmethod
    def getTextBounds(self) -> 'Rectangle_84b109e9':
        """
        """
    @abstractmethod
    def render(self) -> 'XShape_8fd00a3d':
        """
        """

__all__ = ['XCustomShapeEngine']

