# coding: utf-8
#
# Copyright 2022 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Const Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.3
# Namespace: com.sun.star.ui.dialogs
from enum import IntEnum
from typing import TYPE_CHECKING
from ooo.oenv.env_const import UNO_ENVIRONMENT, UNO_RUNTIME
_DYNAMIC = False
if (not TYPE_CHECKING) and UNO_RUNTIME and UNO_ENVIRONMENT:
    _DYNAMIC = True

if not TYPE_CHECKING and _DYNAMIC:
    from com.sun.star.ui.dialogs import ExecutableDialogResults as ExecutableDialogResults
    if hasattr(ExecutableDialogResults, '_constants') and isinstance(ExecutableDialogResults._constants, dict):
        ExecutableDialogResults._constants['__ooo_ns__'] = 'com.sun.star.ui.dialogs'
        ExecutableDialogResults._constants['__ooo_full_ns__'] = 'com.sun.star.ui.dialogs.ExecutableDialogResults'
        ExecutableDialogResults._constants['__ooo_type_name__'] = 'const'
    def build_enum():
        global ExecutableDialogResultsEnum
        ls = [f for f in dir(ExecutableDialogResults) if not callable(getattr(ExecutableDialogResults, f)) and not f.startswith('__')]
        _dict = {}
        for name in ls:
            _dict[name] = getattr(ExecutableDialogResults, name)
        ExecutableDialogResultsEnum = IntEnum('ExecutableDialogResultsEnum', _dict)
    build_enum()
else:
    from ....lo.ui.dialogs.executable_dialog_results import ExecutableDialogResults as ExecutableDialogResults

    class ExecutableDialogResultsEnum(IntEnum):
        """
        Enum of Const Class ExecutableDialogResults

        These constants are used to specify a result of executing a XExecutableDialog.
        """
        CANCEL = ExecutableDialogResults.CANCEL
        """
        The user canceled the dialog.
        """
        OK = ExecutableDialogResults.OK
        """
        The user acknowledged the dialog.
        """

__all__ = ['ExecutableDialogResults', 'ExecutableDialogResultsEnum']
