# coding: utf-8
#
# Copyright 2022 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Const Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.3
# Namespace: com.sun.star.awt
from enum import IntEnum
from typing import TYPE_CHECKING
from ooo.oenv.env_const import UNO_ENVIRONMENT, UNO_RUNTIME
_DYNAMIC = False
if (not TYPE_CHECKING) and UNO_RUNTIME and UNO_ENVIRONMENT:
    _DYNAMIC = True

if not TYPE_CHECKING and _DYNAMIC:
    from com.sun.star.awt import FontStrikeout as FontStrikeout
    if hasattr(FontStrikeout, '_constants') and isinstance(FontStrikeout._constants, dict):
        FontStrikeout._constants['__ooo_ns__'] = 'com.sun.star.awt'
        FontStrikeout._constants['__ooo_full_ns__'] = 'com.sun.star.awt.FontStrikeout'
        FontStrikeout._constants['__ooo_type_name__'] = 'const'
    def build_enum():
        global FontStrikeoutEnum
        ls = [f for f in dir(FontStrikeout) if not callable(getattr(FontStrikeout, f)) and not f.startswith('__')]
        _dict = {}
        for name in ls:
            _dict[name] = getattr(FontStrikeout, name)
        FontStrikeoutEnum = IntEnum('FontStrikeoutEnum', _dict)
    build_enum()
else:
    from ...lo.awt.font_strikeout import FontStrikeout as FontStrikeout

    class FontStrikeoutEnum(IntEnum):
        """
        Enum of Const Class FontStrikeout

        These values are used to specify the kind of strikeout.
        
        They may be expanded in future versions.
        """
        NONE = FontStrikeout.NONE
        """
        specifies not to strike out the characters.
        """
        SINGLE = FontStrikeout.SINGLE
        """
        specifies to strike out the characters with a single line.
        """
        DOUBLE = FontStrikeout.DOUBLE
        """
        specifies to strike out the characters with a double line.
        """
        DONTKNOW = FontStrikeout.DONTKNOW
        """
        The strikeout mode is not specified.
        """
        BOLD = FontStrikeout.BOLD
        """
        specifies to strike out the characters with a bold line.
        """
        SLASH = FontStrikeout.SLASH
        """
        specifies to strike out the characters with slashes.
        """
        X = FontStrikeout.X
        """
        specifies to strike out the characters with X's.
        """

__all__ = ['FontStrikeout', 'FontStrikeoutEnum']
