# coding: utf-8
#
# Copyright 2022 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Const Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.3
# Namespace: com.sun.star.style
from enum import IntEnum
from typing import TYPE_CHECKING
from ooo.oenv.env_const import UNO_ENVIRONMENT, UNO_RUNTIME
_DYNAMIC = False
if (not TYPE_CHECKING) and UNO_RUNTIME and UNO_ENVIRONMENT:
    _DYNAMIC = True

if not TYPE_CHECKING and _DYNAMIC:
    from com.sun.star.style import ParagraphStyleCategory as ParagraphStyleCategory
    if hasattr(ParagraphStyleCategory, '_constants') and isinstance(ParagraphStyleCategory._constants, dict):
        ParagraphStyleCategory._constants['__ooo_ns__'] = 'com.sun.star.style'
        ParagraphStyleCategory._constants['__ooo_full_ns__'] = 'com.sun.star.style.ParagraphStyleCategory'
        ParagraphStyleCategory._constants['__ooo_type_name__'] = 'const'
    def build_enum():
        global ParagraphStyleCategoryEnum
        ls = [f for f in dir(ParagraphStyleCategory) if not callable(getattr(ParagraphStyleCategory, f)) and not f.startswith('__')]
        _dict = {}
        for name in ls:
            _dict[name] = getattr(ParagraphStyleCategory, name)
        ParagraphStyleCategoryEnum = IntEnum('ParagraphStyleCategoryEnum', _dict)
    build_enum()
else:
    from ...lo.style.paragraph_style_category import ParagraphStyleCategory as ParagraphStyleCategory

    class ParagraphStyleCategoryEnum(IntEnum):
        """
        Enum of Const Class ParagraphStyleCategory

        These constants are used to specify the category of paragraph styles in text documents.
        """
        TEXT = ParagraphStyleCategory.TEXT
        """
        is applied to styles that are used for common text.
        """
        CHAPTER = ParagraphStyleCategory.CHAPTER
        """
        is applied to styles that are used as headings.
        """
        LIST = ParagraphStyleCategory.LIST
        """
        is applied to styles that used in numberings and lists.
        """
        INDEX = ParagraphStyleCategory.INDEX
        """
        is applied to styles that are used in indexes.
        """
        EXTRA = ParagraphStyleCategory.EXTRA
        """
        is applied to styles that are used in special regions like headers, footers, and footnote text.
        """
        HTML = ParagraphStyleCategory.HTML
        """
        is applied to styles that are used to support HTML.
        """

__all__ = ['ParagraphStyleCategory', 'ParagraphStyleCategoryEnum']
