# coding: utf-8
#
# Copyright 2022 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Enum Class
# this is a auto generated file generated by Cheetah
# Namespace: com.sun.star.xml.xpath
# Libre Office Version: 7.3
from typing import TYPE_CHECKING
from ooo.oenv.env_const import UNO_ENVIRONMENT, UNO_RUNTIME
_DYNAMIC = False
if (not TYPE_CHECKING) and UNO_RUNTIME and UNO_ENVIRONMENT:
    _DYNAMIC = True

if not TYPE_CHECKING and _DYNAMIC:
    from ooo.helper.enum_helper import uno_enum_class_new
    from com.sun.star.xml.xpath.XPathObjectType import (XPATH_BOOLEAN, XPATH_LOCATIONSET, XPATH_NODESET, XPATH_NUMBER, XPATH_POINT, XPATH_RANGE, XPATH_STRING, XPATH_UNDEFINED, XPATH_USERS, XPATH_XSLT_TREE)

    def _get_enum():
        # Dynamically create class that actually contains UNO enum instances
        _dict = {
            "__doc__": "Dynamically created class that represents com.sun.star.xml.xpath.XPathObjectType Enum. Class loosly mimics Enum",
            "__new__": uno_enum_class_new,
            "__ooo_ns__": "com.sun.star.xml.xpath",
            "__ooo_full_ns__": "com.sun.star.xml.xpath.XPathObjectType",
            "__ooo_type_name__": "enum",
            "XPATH_BOOLEAN": XPATH_BOOLEAN,
            "XPATH_LOCATIONSET": XPATH_LOCATIONSET,
            "XPATH_NODESET": XPATH_NODESET,
            "XPATH_NUMBER": XPATH_NUMBER,
            "XPATH_POINT": XPATH_POINT,
            "XPATH_RANGE": XPATH_RANGE,
            "XPATH_STRING": XPATH_STRING,
            "XPATH_UNDEFINED": XPATH_UNDEFINED,
            "XPATH_USERS": XPATH_USERS,
            "XPATH_XSLT_TREE": XPATH_XSLT_TREE,
        }
        result = type('XPathObjectType', (object,), _dict)
        return result

    XPathObjectType = _get_enum()
else:
    from ....lo.xml.xpath.x_path_object_type import XPathObjectType as XPathObjectType

__all__ = ['XPathObjectType']

