# coding: utf-8
#
# Copyright 2022 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Const Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.3
# Namespace: com.sun.star.ucb
from enum import IntEnum
from typing import TYPE_CHECKING
from ooo.oenv.env_const import UNO_ENVIRONMENT, UNO_RUNTIME
_DYNAMIC = False
if (not TYPE_CHECKING) and UNO_RUNTIME and UNO_ENVIRONMENT:
    _DYNAMIC = True

if not TYPE_CHECKING and _DYNAMIC:
    from com.sun.star.ucb import ConnectionMode as ConnectionMode
    if hasattr(ConnectionMode, '_constants') and isinstance(ConnectionMode._constants, dict):
        ConnectionMode._constants['__ooo_ns__'] = 'com.sun.star.ucb'
        ConnectionMode._constants['__ooo_full_ns__'] = 'com.sun.star.ucb.ConnectionMode'
        ConnectionMode._constants['__ooo_type_name__'] = 'const'
    def build_enum():
        global ConnectionModeEnum
        ls = [f for f in dir(ConnectionMode) if not callable(getattr(ConnectionMode, f)) and not f.startswith('__')]
        _dict = {}
        for name in ls:
            _dict[name] = getattr(ConnectionMode, name)
        ConnectionModeEnum = IntEnum('ConnectionModeEnum', _dict)
    build_enum()
else:
    from ...lo.ucb.connection_mode import ConnectionMode as ConnectionMode

    class ConnectionModeEnum(IntEnum):
        """
        Enum of Const Class ConnectionMode

        These are the possible values for the property \"ConnectionMode\".
        """
        ONLINE = ConnectionMode.ONLINE
        """
        \"Online\" - Network access is allowed.
        """
        OFFLINE = ConnectionMode.OFFLINE
        """
        \"Offline\" - Network access is not allowed.
        """

__all__ = ['ConnectionMode', 'ConnectionModeEnum']
