# coding: utf-8
#
# Copyright 2022 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Enum Class
# this is a auto generated file generated by Cheetah
# Namespace: com.sun.star.presentation
# Libre Office Version: 7.3
from typing import TYPE_CHECKING
from ooo.oenv.env_const import UNO_ENVIRONMENT, UNO_RUNTIME
_DYNAMIC = False
if (not TYPE_CHECKING) and UNO_RUNTIME and UNO_ENVIRONMENT:
    _DYNAMIC = True

if not TYPE_CHECKING and _DYNAMIC:
    from ooo.helper.enum_helper import uno_enum_class_new
    from com.sun.star.presentation.AnimationEffect import (APPEAR, CLOCKWISE, CLOSE_HORIZONTAL, CLOSE_VERTICAL, COUNTERCLOCKWISE, DISSOLVE, FADE_FROM_BOTTOM, FADE_FROM_CENTER, FADE_FROM_LEFT, FADE_FROM_LOWERLEFT, FADE_FROM_LOWERRIGHT, FADE_FROM_RIGHT, FADE_FROM_TOP, FADE_FROM_UPPERLEFT, FADE_FROM_UPPERRIGHT, FADE_TO_CENTER, HIDE, HORIZONTAL_CHECKERBOARD, HORIZONTAL_LINES, HORIZONTAL_ROTATE, HORIZONTAL_STRETCH, HORIZONTAL_STRIPES, LASER_FROM_BOTTOM, LASER_FROM_LEFT, LASER_FROM_LOWERLEFT, LASER_FROM_LOWERRIGHT, LASER_FROM_RIGHT, LASER_FROM_TOP, LASER_FROM_UPPERLEFT, LASER_FROM_UPPERRIGHT, MOVE_FROM_BOTTOM, MOVE_FROM_LEFT, MOVE_FROM_LOWERLEFT, MOVE_FROM_LOWERRIGHT, MOVE_FROM_RIGHT, MOVE_FROM_TOP, MOVE_FROM_UPPERLEFT, MOVE_FROM_UPPERRIGHT, MOVE_SHORT_FROM_BOTTOM, MOVE_SHORT_FROM_LEFT, MOVE_SHORT_FROM_LOWERLEFT, MOVE_SHORT_FROM_LOWERRIGHT, MOVE_SHORT_FROM_RIGHT, MOVE_SHORT_FROM_TOP, MOVE_SHORT_FROM_UPPERLEFT, MOVE_SHORT_FROM_UPPERRIGHT, MOVE_SHORT_TO_BOTTOM, MOVE_SHORT_TO_LEFT, MOVE_SHORT_TO_LOWERLEFT, MOVE_SHORT_TO_LOWERRIGHT, MOVE_SHORT_TO_RIGHT, MOVE_SHORT_TO_TOP, MOVE_SHORT_TO_UPPERLEFT, MOVE_SHORT_TO_UPPERRIGHT, MOVE_TO_BOTTOM, MOVE_TO_LEFT, MOVE_TO_LOWERLEFT, MOVE_TO_LOWERRIGHT, MOVE_TO_RIGHT, MOVE_TO_TOP, MOVE_TO_UPPERLEFT, MOVE_TO_UPPERRIGHT, NONE, OPEN_HORIZONTAL, OPEN_VERTICAL, PATH, RANDOM, SPIRALIN_LEFT, SPIRALIN_RIGHT, SPIRALOUT_LEFT, SPIRALOUT_RIGHT, STRETCH_FROM_BOTTOM, STRETCH_FROM_LEFT, STRETCH_FROM_LOWERLEFT, STRETCH_FROM_LOWERRIGHT, STRETCH_FROM_RIGHT, STRETCH_FROM_TOP, STRETCH_FROM_UPPERLEFT, STRETCH_FROM_UPPERRIGHT, VERTICAL_CHECKERBOARD, VERTICAL_LINES, VERTICAL_ROTATE, VERTICAL_STRETCH, VERTICAL_STRIPES, WAVYLINE_FROM_BOTTOM, WAVYLINE_FROM_LEFT, WAVYLINE_FROM_RIGHT, WAVYLINE_FROM_TOP, ZOOM_IN, ZOOM_IN_FROM_BOTTOM, ZOOM_IN_FROM_CENTER, ZOOM_IN_FROM_LEFT, ZOOM_IN_FROM_LOWERLEFT, ZOOM_IN_FROM_LOWERRIGHT, ZOOM_IN_FROM_RIGHT, ZOOM_IN_FROM_TOP, ZOOM_IN_FROM_UPPERLEFT, ZOOM_IN_FROM_UPPERRIGHT, ZOOM_IN_SMALL, ZOOM_IN_SPIRAL, ZOOM_OUT, ZOOM_OUT_FROM_BOTTOM, ZOOM_OUT_FROM_CENTER, ZOOM_OUT_FROM_LEFT, ZOOM_OUT_FROM_LOWERLEFT, ZOOM_OUT_FROM_LOWERRIGHT, ZOOM_OUT_FROM_RIGHT, ZOOM_OUT_FROM_TOP, ZOOM_OUT_FROM_UPPERLEFT, ZOOM_OUT_FROM_UPPERRIGHT, ZOOM_OUT_SMALL, ZOOM_OUT_SPIRAL)

    def _get_enum():
        # Dynamically create class that actually contains UNO enum instances
        _dict = {
            "__doc__": "Dynamically created class that represents com.sun.star.presentation.AnimationEffect Enum. Class loosly mimics Enum",
            "__new__": uno_enum_class_new,
            "__ooo_ns__": "com.sun.star.presentation",
            "__ooo_full_ns__": "com.sun.star.presentation.AnimationEffect",
            "__ooo_type_name__": "enum",
            "APPEAR": APPEAR,
            "CLOCKWISE": CLOCKWISE,
            "CLOSE_HORIZONTAL": CLOSE_HORIZONTAL,
            "CLOSE_VERTICAL": CLOSE_VERTICAL,
            "COUNTERCLOCKWISE": COUNTERCLOCKWISE,
            "DISSOLVE": DISSOLVE,
            "FADE_FROM_BOTTOM": FADE_FROM_BOTTOM,
            "FADE_FROM_CENTER": FADE_FROM_CENTER,
            "FADE_FROM_LEFT": FADE_FROM_LEFT,
            "FADE_FROM_LOWERLEFT": FADE_FROM_LOWERLEFT,
            "FADE_FROM_LOWERRIGHT": FADE_FROM_LOWERRIGHT,
            "FADE_FROM_RIGHT": FADE_FROM_RIGHT,
            "FADE_FROM_TOP": FADE_FROM_TOP,
            "FADE_FROM_UPPERLEFT": FADE_FROM_UPPERLEFT,
            "FADE_FROM_UPPERRIGHT": FADE_FROM_UPPERRIGHT,
            "FADE_TO_CENTER": FADE_TO_CENTER,
            "HIDE": HIDE,
            "HORIZONTAL_CHECKERBOARD": HORIZONTAL_CHECKERBOARD,
            "HORIZONTAL_LINES": HORIZONTAL_LINES,
            "HORIZONTAL_ROTATE": HORIZONTAL_ROTATE,
            "HORIZONTAL_STRETCH": HORIZONTAL_STRETCH,
            "HORIZONTAL_STRIPES": HORIZONTAL_STRIPES,
            "LASER_FROM_BOTTOM": LASER_FROM_BOTTOM,
            "LASER_FROM_LEFT": LASER_FROM_LEFT,
            "LASER_FROM_LOWERLEFT": LASER_FROM_LOWERLEFT,
            "LASER_FROM_LOWERRIGHT": LASER_FROM_LOWERRIGHT,
            "LASER_FROM_RIGHT": LASER_FROM_RIGHT,
            "LASER_FROM_TOP": LASER_FROM_TOP,
            "LASER_FROM_UPPERLEFT": LASER_FROM_UPPERLEFT,
            "LASER_FROM_UPPERRIGHT": LASER_FROM_UPPERRIGHT,
            "MOVE_FROM_BOTTOM": MOVE_FROM_BOTTOM,
            "MOVE_FROM_LEFT": MOVE_FROM_LEFT,
            "MOVE_FROM_LOWERLEFT": MOVE_FROM_LOWERLEFT,
            "MOVE_FROM_LOWERRIGHT": MOVE_FROM_LOWERRIGHT,
            "MOVE_FROM_RIGHT": MOVE_FROM_RIGHT,
            "MOVE_FROM_TOP": MOVE_FROM_TOP,
            "MOVE_FROM_UPPERLEFT": MOVE_FROM_UPPERLEFT,
            "MOVE_FROM_UPPERRIGHT": MOVE_FROM_UPPERRIGHT,
            "MOVE_SHORT_FROM_BOTTOM": MOVE_SHORT_FROM_BOTTOM,
            "MOVE_SHORT_FROM_LEFT": MOVE_SHORT_FROM_LEFT,
            "MOVE_SHORT_FROM_LOWERLEFT": MOVE_SHORT_FROM_LOWERLEFT,
            "MOVE_SHORT_FROM_LOWERRIGHT": MOVE_SHORT_FROM_LOWERRIGHT,
            "MOVE_SHORT_FROM_RIGHT": MOVE_SHORT_FROM_RIGHT,
            "MOVE_SHORT_FROM_TOP": MOVE_SHORT_FROM_TOP,
            "MOVE_SHORT_FROM_UPPERLEFT": MOVE_SHORT_FROM_UPPERLEFT,
            "MOVE_SHORT_FROM_UPPERRIGHT": MOVE_SHORT_FROM_UPPERRIGHT,
            "MOVE_SHORT_TO_BOTTOM": MOVE_SHORT_TO_BOTTOM,
            "MOVE_SHORT_TO_LEFT": MOVE_SHORT_TO_LEFT,
            "MOVE_SHORT_TO_LOWERLEFT": MOVE_SHORT_TO_LOWERLEFT,
            "MOVE_SHORT_TO_LOWERRIGHT": MOVE_SHORT_TO_LOWERRIGHT,
            "MOVE_SHORT_TO_RIGHT": MOVE_SHORT_TO_RIGHT,
            "MOVE_SHORT_TO_TOP": MOVE_SHORT_TO_TOP,
            "MOVE_SHORT_TO_UPPERLEFT": MOVE_SHORT_TO_UPPERLEFT,
            "MOVE_SHORT_TO_UPPERRIGHT": MOVE_SHORT_TO_UPPERRIGHT,
            "MOVE_TO_BOTTOM": MOVE_TO_BOTTOM,
            "MOVE_TO_LEFT": MOVE_TO_LEFT,
            "MOVE_TO_LOWERLEFT": MOVE_TO_LOWERLEFT,
            "MOVE_TO_LOWERRIGHT": MOVE_TO_LOWERRIGHT,
            "MOVE_TO_RIGHT": MOVE_TO_RIGHT,
            "MOVE_TO_TOP": MOVE_TO_TOP,
            "MOVE_TO_UPPERLEFT": MOVE_TO_UPPERLEFT,
            "MOVE_TO_UPPERRIGHT": MOVE_TO_UPPERRIGHT,
            "NONE": NONE,
            "OPEN_HORIZONTAL": OPEN_HORIZONTAL,
            "OPEN_VERTICAL": OPEN_VERTICAL,
            "PATH": PATH,
            "RANDOM": RANDOM,
            "SPIRALIN_LEFT": SPIRALIN_LEFT,
            "SPIRALIN_RIGHT": SPIRALIN_RIGHT,
            "SPIRALOUT_LEFT": SPIRALOUT_LEFT,
            "SPIRALOUT_RIGHT": SPIRALOUT_RIGHT,
            "STRETCH_FROM_BOTTOM": STRETCH_FROM_BOTTOM,
            "STRETCH_FROM_LEFT": STRETCH_FROM_LEFT,
            "STRETCH_FROM_LOWERLEFT": STRETCH_FROM_LOWERLEFT,
            "STRETCH_FROM_LOWERRIGHT": STRETCH_FROM_LOWERRIGHT,
            "STRETCH_FROM_RIGHT": STRETCH_FROM_RIGHT,
            "STRETCH_FROM_TOP": STRETCH_FROM_TOP,
            "STRETCH_FROM_UPPERLEFT": STRETCH_FROM_UPPERLEFT,
            "STRETCH_FROM_UPPERRIGHT": STRETCH_FROM_UPPERRIGHT,
            "VERTICAL_CHECKERBOARD": VERTICAL_CHECKERBOARD,
            "VERTICAL_LINES": VERTICAL_LINES,
            "VERTICAL_ROTATE": VERTICAL_ROTATE,
            "VERTICAL_STRETCH": VERTICAL_STRETCH,
            "VERTICAL_STRIPES": VERTICAL_STRIPES,
            "WAVYLINE_FROM_BOTTOM": WAVYLINE_FROM_BOTTOM,
            "WAVYLINE_FROM_LEFT": WAVYLINE_FROM_LEFT,
            "WAVYLINE_FROM_RIGHT": WAVYLINE_FROM_RIGHT,
            "WAVYLINE_FROM_TOP": WAVYLINE_FROM_TOP,
            "ZOOM_IN": ZOOM_IN,
            "ZOOM_IN_FROM_BOTTOM": ZOOM_IN_FROM_BOTTOM,
            "ZOOM_IN_FROM_CENTER": ZOOM_IN_FROM_CENTER,
            "ZOOM_IN_FROM_LEFT": ZOOM_IN_FROM_LEFT,
            "ZOOM_IN_FROM_LOWERLEFT": ZOOM_IN_FROM_LOWERLEFT,
            "ZOOM_IN_FROM_LOWERRIGHT": ZOOM_IN_FROM_LOWERRIGHT,
            "ZOOM_IN_FROM_RIGHT": ZOOM_IN_FROM_RIGHT,
            "ZOOM_IN_FROM_TOP": ZOOM_IN_FROM_TOP,
            "ZOOM_IN_FROM_UPPERLEFT": ZOOM_IN_FROM_UPPERLEFT,
            "ZOOM_IN_FROM_UPPERRIGHT": ZOOM_IN_FROM_UPPERRIGHT,
            "ZOOM_IN_SMALL": ZOOM_IN_SMALL,
            "ZOOM_IN_SPIRAL": ZOOM_IN_SPIRAL,
            "ZOOM_OUT": ZOOM_OUT,
            "ZOOM_OUT_FROM_BOTTOM": ZOOM_OUT_FROM_BOTTOM,
            "ZOOM_OUT_FROM_CENTER": ZOOM_OUT_FROM_CENTER,
            "ZOOM_OUT_FROM_LEFT": ZOOM_OUT_FROM_LEFT,
            "ZOOM_OUT_FROM_LOWERLEFT": ZOOM_OUT_FROM_LOWERLEFT,
            "ZOOM_OUT_FROM_LOWERRIGHT": ZOOM_OUT_FROM_LOWERRIGHT,
            "ZOOM_OUT_FROM_RIGHT": ZOOM_OUT_FROM_RIGHT,
            "ZOOM_OUT_FROM_TOP": ZOOM_OUT_FROM_TOP,
            "ZOOM_OUT_FROM_UPPERLEFT": ZOOM_OUT_FROM_UPPERLEFT,
            "ZOOM_OUT_FROM_UPPERRIGHT": ZOOM_OUT_FROM_UPPERRIGHT,
            "ZOOM_OUT_SMALL": ZOOM_OUT_SMALL,
            "ZOOM_OUT_SPIRAL": ZOOM_OUT_SPIRAL,
        }
        result = type('AnimationEffect', (object,), _dict)
        return result

    AnimationEffect = _get_enum()
else:
    from ...lo.presentation.animation_effect import AnimationEffect as AnimationEffect

__all__ = ['AnimationEffect']

