# coding: utf-8
#
# Copyright 2022 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Const Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.3
# Namespace: com.sun.star.sdbc
from enum import IntEnum
from typing import TYPE_CHECKING
from ooo.oenv.env_const import UNO_ENVIRONMENT, UNO_RUNTIME
_DYNAMIC = False
if (not TYPE_CHECKING) and UNO_RUNTIME and UNO_ENVIRONMENT:
    _DYNAMIC = True

if not TYPE_CHECKING and _DYNAMIC:
    from com.sun.star.sdbc import ProcedureResult as ProcedureResult
    if hasattr(ProcedureResult, '_constants') and isinstance(ProcedureResult._constants, dict):
        ProcedureResult._constants['__ooo_ns__'] = 'com.sun.star.sdbc'
        ProcedureResult._constants['__ooo_full_ns__'] = 'com.sun.star.sdbc.ProcedureResult'
        ProcedureResult._constants['__ooo_type_name__'] = 'const'
    def build_enum():
        global ProcedureResultEnum
        ls = [f for f in dir(ProcedureResult) if not callable(getattr(ProcedureResult, f)) and not f.startswith('__')]
        _dict = {}
        for name in ls:
            _dict[name] = getattr(ProcedureResult, name)
        ProcedureResultEnum = IntEnum('ProcedureResultEnum', _dict)
    build_enum()
else:
    from ...lo.sdbc.procedure_result import ProcedureResult as ProcedureResult

    class ProcedureResultEnum(IntEnum):
        """
        Enum of Const Class ProcedureResult

        determines whether a procedure returns a result or not.
        """
        UNKNOWN = ProcedureResult.UNKNOWN
        """
        A possible value for column PROCEDURE_TYPE in the com.sun.star.sdbc.XResultSet object returned by the method com.sun.star.sdbc.XDatabaseMetaData.getProcedures().
        
        Indicates that it is not known whether the procedure returns a result.
        """
        NONE = ProcedureResult.NONE
        """
        A possible value for column PROCEDURE_TYPE in the com.sun.star.sdbc.XResultSet object returned by the method com.sun.star.sdbc.XDatabaseMetaData.getProcedures().
        
        Indicates that the procedure does not return a result.
        """
        RETURN = ProcedureResult.RETURN
        """
        A possible value for column PROCEDURE_TYPE in the com.sun.star.sdbc.XResultSet object returned by the method com.sun.star.sdbc.XDatabaseMetaData.getProcedures().
        
        Indicates that the procedure returns a result.
        """

__all__ = ['ProcedureResult', 'ProcedureResultEnum']
