# coding: utf-8
#
# Copyright 2022 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Service Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.3
# Namespace: com.sun.star.form
import typing
from abc import abstractmethod
from ..ui.dialogs.x_executable_dialog import XExecutableDialog as XExecutableDialog_450f0fa1
if typing.TYPE_CHECKING:
    from ..awt.x_control_container import XControlContainer as XControlContainer_e22d0d30
    from ..awt.x_tab_controller_model import XTabControllerModel as XTabControllerModel_fbef0dd8
    from ..awt.x_window import XWindow as XWindow_713b0924

class TabOrderDialog(XExecutableDialog_450f0fa1):
    """
    Service Class

    
    **since**
    
        LibreOffice 4.2

    See Also:
        `API TabOrderDialog <https://api.libreoffice.org/docs/idl/ref/servicecom_1_1sun_1_1star_1_1form_1_1TabOrderDialog.html>`_
    """
    __ooo_ns__: str = 'com.sun.star.form'
    __ooo_full_ns__: str = 'com.sun.star.form.TabOrderDialog'
    __ooo_type_name__: str = 'service'

    @abstractmethod
    def createWithModel(self, TabbingModel: 'XTabControllerModel_fbef0dd8', ControlContext: 'XControlContainer_e22d0d30', ParentWindow: 'XWindow_713b0924') -> None:
        """
        """


__all__ = ['TabOrderDialog']

