# coding: utf-8
#
# Copyright 2022 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Interface Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.3
# Namespace: com.sun.star.chart2
import typing
from abc import abstractmethod
from ..uno.x_interface import XInterface as XInterface_8f010a43
if typing.TYPE_CHECKING:
    from .x_coordinate_system import XCoordinateSystem as XCoordinateSystem_7ff0e31

class XCoordinateSystemContainer(XInterface_8f010a43):
    """

    See Also:
        `API XCoordinateSystemContainer <https://api.libreoffice.org/docs/idl/ref/interfacecom_1_1sun_1_1star_1_1chart2_1_1XCoordinateSystemContainer.html>`_
    """
    __ooo_ns__: str = 'com.sun.star.chart2'
    __ooo_full_ns__: str = 'com.sun.star.chart2.XCoordinateSystemContainer'
    __ooo_type_name__: str = 'interface'
    __pyunointerface__: str = 'com.sun.star.chart2.XCoordinateSystemContainer'

    @abstractmethod
    def addCoordinateSystem(self, aCoordSys: 'XCoordinateSystem_7ff0e31') -> None:
        """
        add a coordinate system to the coordinate system container

        Raises:
            com.sun.star.lang.IllegalArgumentException: ``IllegalArgumentException``
        """
    @abstractmethod
    def getCoordinateSystems(self) -> 'typing.Tuple[XCoordinateSystem_7ff0e31, ...]':
        """
        retrieve all coordinate systems
        """
    @abstractmethod
    def removeCoordinateSystem(self, aCoordSys: 'XCoordinateSystem_7ff0e31') -> None:
        """
        removes one coordinate system from the coordinate system container.

        Raises:
            com.sun.star.container.NoSuchElementException: ``NoSuchElementException``
        """
    @abstractmethod
    def setCoordinateSystems(self, aCoordinateSystems: 'typing.Tuple[XCoordinateSystem_7ff0e31, ...]') -> None:
        """
        set all coordinate systems

        Raises:
            com.sun.star.lang.IllegalArgumentException: ``IllegalArgumentException``
        """

__all__ = ['XCoordinateSystemContainer']

