# coding: utf-8
#
# Copyright 2022 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Interface Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.3
# Namespace: com.sun.star.drawing.framework
import typing
from abc import abstractmethod, ABC
if typing.TYPE_CHECKING:
    from .x_configuration_controller import XConfigurationController as XConfigurationController_557c15c4
    from .x_module_controller import XModuleController as XModuleController_c5d112d2

class XControllerManager(ABC):
    """
    The XControllerManager gives access to the controllers of the drawing framework.
    
    The XControllerManager interface is typically implemented by the same object that implements com.sun.star.frame.XController.

    See Also:
        `API XControllerManager <https://api.libreoffice.org/docs/idl/ref/interfacecom_1_1sun_1_1star_1_1drawing_1_1framework_1_1XControllerManager.html>`_
    """
    __ooo_ns__: str = 'com.sun.star.drawing.framework'
    __ooo_full_ns__: str = 'com.sun.star.drawing.framework.XControllerManager'
    __ooo_type_name__: str = 'interface'
    __pyunointerface__: str = 'com.sun.star.drawing.framework.XControllerManager'

    @abstractmethod
    def getConfigurationController(self) -> 'XConfigurationController_557c15c4':
        """
        Return the XConfigurationController object.
        """
    @abstractmethod
    def getModuleController(self) -> 'XModuleController_c5d112d2':
        """
        Return the XModuleController object.
        """

__all__ = ['XControllerManager']

