# coding: utf-8
#
# Copyright 2022 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Service Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.3
# Namespace: com.sun.star.frame
from .x_notifying_dispatch import XNotifyingDispatch as XNotifyingDispatch_bc10e52

class ContentHandler(XNotifyingDispatch_bc10e52):
    """
    Service Class

    special dispatcher for non visible contents, e.g.
    
    sounds
    
    This handler doesn't need any frame as target for loading components. Content handler are registered for content types. (See type/filter configuration of com.sun.star.document.TypeDetection for further information) If generic load mechanism found such documents which can be handled by a ContentHandler it will create and use it.

    See Also:
        `API ContentHandler <https://api.libreoffice.org/docs/idl/ref/servicecom_1_1sun_1_1star_1_1frame_1_1ContentHandler.html>`_
    """
    __ooo_ns__: str = 'com.sun.star.frame'
    __ooo_full_ns__: str = 'com.sun.star.frame.ContentHandler'
    __ooo_type_name__: str = 'service'



__all__ = ['ContentHandler']

