# coding: utf-8
#
# Copyright 2022 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Interface Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.3
# Namespace: com.sun.star.office
import typing
from abc import abstractmethod, ABC
if typing.TYPE_CHECKING:
    from .x_annotation import XAnnotation as XAnnotation_bb8f0be7

class XAnnotationEnumeration(ABC):
    """
    An enumeration for a set of annotations.

    See Also:
        `API XAnnotationEnumeration <https://api.libreoffice.org/docs/idl/ref/interfacecom_1_1sun_1_1star_1_1office_1_1XAnnotationEnumeration.html>`_
    """
    __ooo_ns__: str = 'com.sun.star.office'
    __ooo_full_ns__: str = 'com.sun.star.office.XAnnotationEnumeration'
    __ooo_type_name__: str = 'interface'
    __pyunointerface__: str = 'com.sun.star.office.XAnnotationEnumeration'

    @abstractmethod
    def hasMoreElements(self) -> bool:
        """
        tests whether this enumeration contains more elements.
        """
    @abstractmethod
    def nextElement(self) -> 'XAnnotation_bb8f0be7':
        """

        Raises:
            com.sun.star.container.NoSuchElementException: ``NoSuchElementException``
        """

__all__ = ['XAnnotationEnumeration']

