# coding: utf-8
#
# Copyright 2022 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Service Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.3
# Namespace: com.sun.star.text
from abc import abstractproperty
from .base_index import BaseIndex as BaseIndex_8f0d0a40

class ObjectIndex(BaseIndex_8f0d0a40):
    """
    Service Class

    specifies service of object indexes within a document.

    See Also:
        `API ObjectIndex <https://api.libreoffice.org/docs/idl/ref/servicecom_1_1sun_1_1star_1_1text_1_1ObjectIndex.html>`_
    """
    __ooo_ns__: str = 'com.sun.star.text'
    __ooo_full_ns__: str = 'com.sun.star.text.ObjectIndex'
    __ooo_type_name__: str = 'service'

    @abstractproperty
    def CreateFromOtherEmbeddedObjects(self) -> bool:
        """
        Determines if external embedded objects are included in the office.
        """

    @abstractproperty
    def CreateFromStarCalc(self) -> bool:
        """
        Determines if star office calc objects are included in the office.
        """

    @abstractproperty
    def CreateFromStarChart(self) -> bool:
        """
        Determines if star office chart objects are included in the office.
        """

    @abstractproperty
    def CreateFromStarDraw(self) -> bool:
        """
        Determines if star office draw objects are included in the office.
        """

    @abstractproperty
    def CreateFromStarImage(self) -> bool:
        """
        Determines if star office image objects are included in the office.
        """

    @abstractproperty
    def CreateFromStarMath(self) -> bool:
        """
        Determines if star office math objects are included in the office.
        """



__all__ = ['ObjectIndex']

