# coding: utf-8
#
# Copyright 2022 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Const Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.3
# Namespace: com.sun.star.sdbc
from enum import IntEnum
from typing import TYPE_CHECKING
from ooo.oenv.env_const import UNO_ENVIRONMENT, UNO_RUNTIME
_DYNAMIC = False
if (not TYPE_CHECKING) and UNO_RUNTIME and UNO_ENVIRONMENT:
    _DYNAMIC = True

if not TYPE_CHECKING and _DYNAMIC:
    from com.sun.star.sdbc import BestRowType as BestRowType
    if hasattr(BestRowType, '_constants') and isinstance(BestRowType._constants, dict):
        BestRowType._constants['__ooo_ns__'] = 'com.sun.star.sdbc'
        BestRowType._constants['__ooo_full_ns__'] = 'com.sun.star.sdbc.BestRowType'
        BestRowType._constants['__ooo_type_name__'] = 'const'
    def build_enum():
        global BestRowTypeEnum
        ls = [f for f in dir(BestRowType) if not callable(getattr(BestRowType, f)) and not f.startswith('__')]
        _dict = {}
        for name in ls:
            _dict[name] = getattr(BestRowType, name)
        BestRowTypeEnum = IntEnum('BestRowTypeEnum', _dict)
    build_enum()
else:
    from ...lo.sdbc.best_row_type import BestRowType as BestRowType

    class BestRowTypeEnum(IntEnum):
        """
        Enum of Const Class BestRowType

        determines the type of the best row identifier.
        """
        UNKNOWN = BestRowType.UNKNOWN
        """
        indicates that the best row identifier may or may not be a pseudo-column.
        
        A possible value for the column PSEUDO_COLUMN in the com.sun.star.sdbc.XResultSet object returned by the method XDatabaseMetaData.getBestRowIdentifier().
        """
        NOT_PSEUDO = BestRowType.NOT_PSEUDO
        """
        indicates that the best row identifier is NOT a pseudo-column.
        
        A possible value for the column PSEUDO_COLUMN in the com.sun.star.sdbc.XResultSet object returned by the method XDatabaseMetaData.getBestRowIdentifier().
        """
        PSEUDO = BestRowType.PSEUDO
        """
        indicates that the best row identifier is a pseudo-column.
        
        A possible value for the column PSEUDO_COLUMN in the com.sun.star.sdbc.XResultSet object returned by the method XDatabaseMetaData.getBestRowIdentifier().
        """

__all__ = ['BestRowType', 'BestRowTypeEnum']
