# coding: utf-8
#
# Copyright 2022 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Interface Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.3
# Namespace: com.sun.star.io
import typing
from abc import abstractmethod
from .x_data_output_stream import XDataOutputStream as XDataOutputStream_d2f40caf
if typing.TYPE_CHECKING:
    from .x_persist_object import XPersistObject as XPersistObject_af2f0b79

class XObjectOutputStream(XDataOutputStream_d2f40caf):
    """
    stores XPersistObject implementations into the stream
    
    An implementation of the type XPersistObject uses this interface to write its internal state into a stream. Have a look there for the explanation of the concept.

    See Also:
        `API XObjectOutputStream <https://api.libreoffice.org/docs/idl/ref/interfacecom_1_1sun_1_1star_1_1io_1_1XObjectOutputStream.html>`_
    """
    __ooo_ns__: str = 'com.sun.star.io'
    __ooo_full_ns__: str = 'com.sun.star.io.XObjectOutputStream'
    __ooo_type_name__: str = 'interface'
    __pyunointerface__: str = 'com.sun.star.io.XObjectOutputStream'

    @abstractmethod
    def writeObject(self, Object: 'XPersistObject_af2f0b79') -> None:
        """
        writes an object to the stream.

        Raises:
            IOException: ``IOException``
        """

__all__ = ['XObjectOutputStream']

