# coding: utf-8
#
# Copyright 2022 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
from ...dyn.frame.app_dispatch_provider import AppDispatchProvider as AppDispatchProvider
from ...dyn.frame.auto_recovery import AutoRecovery as AutoRecovery
from ...dyn.frame.bibliography import Bibliography as Bibliography
from ...dyn.frame.border_widths import BorderWidths as BorderWidths
from ...dyn.frame.command_group import CommandGroup as CommandGroup
from ...dyn.frame.command_group import CommandGroupEnum as CommandGroupEnum
from ...dyn.frame.components import Components as Components
from ...dyn.frame.content_handler import ContentHandler as ContentHandler
from ...dyn.frame.content_handler_factory import ContentHandlerFactory as ContentHandlerFactory
from ...dyn.frame.control_command import ControlCommand as ControlCommand
from ...dyn.frame.control_event import ControlEvent as ControlEvent
from ...dyn.frame.controller import Controller as Controller
from ...dyn.frame.desktop import Desktop as Desktop
from ...dyn.frame.desktop_task import DesktopTask as DesktopTask
from ...dyn.frame.desktop_tasks import DesktopTasks as DesktopTasks
from ...dyn.frame.dispatch_descriptor import DispatchDescriptor as DispatchDescriptor
from ...dyn.frame.dispatch_helper import DispatchHelper as DispatchHelper
from ...dyn.frame.dispatch_information import DispatchInformation as DispatchInformation
from ...dyn.frame.dispatch_provider import DispatchProvider as DispatchProvider
from ...dyn.frame.dispatch_recorder import DispatchRecorder as DispatchRecorder
from ...dyn.frame.dispatch_recorder_supplier import DispatchRecorderSupplier as DispatchRecorderSupplier
from ...dyn.frame.dispatch_result_event import DispatchResultEvent as DispatchResultEvent
from ...dyn.frame.dispatch_result_state import DispatchResultState as DispatchResultState
from ...dyn.frame.dispatch_result_state import DispatchResultStateEnum as DispatchResultStateEnum
from ...dyn.frame.dispatch_statement import DispatchStatement as DispatchStatement
from ...dyn.frame.document_templates import DocumentTemplates as DocumentTemplates
from ...dyn.frame.double_initialization_exception import DoubleInitializationException as DoubleInitializationException
from ...dyn.frame.feature_state_event import FeatureStateEvent as FeatureStateEvent
from ...dyn.frame.frame import Frame as Frame
from ...dyn.frame.frame_action import FrameAction as FrameAction
from ...dyn.frame.frame_action_event import FrameActionEvent as FrameActionEvent
from ...dyn.frame.frame_control import FrameControl as FrameControl
from ...dyn.frame.frame_loader import FrameLoader as FrameLoader
from ...dyn.frame.frame_loader_factory import FrameLoaderFactory as FrameLoaderFactory
from ...dyn.frame.frame_search_flag import FrameSearchFlag as FrameSearchFlag
from ...dyn.frame.frame_search_flag import FrameSearchFlagEnum as FrameSearchFlagEnum
from ...dyn.frame.frames_container import FramesContainer as FramesContainer
from ...dyn.frame.global_event_broadcaster import GlobalEventBroadcaster as GlobalEventBroadcaster
from ...dyn.frame.illegal_argument_io_exception import IllegalArgumentIOException as IllegalArgumentIOException
from ...dyn.frame.infobar_type import InfobarType as InfobarType
from ...dyn.frame.infobar_type import InfobarTypeEnum as InfobarTypeEnum
from ...dyn.frame.layout_manager import LayoutManager as LayoutManager
from ...dyn.frame.layout_manager_events import LayoutManagerEvents as LayoutManagerEvents
from ...dyn.frame.layout_manager_events import LayoutManagerEventsEnum as LayoutManagerEventsEnum
from ...dyn.frame.media_type_detection_helper import MediaTypeDetectionHelper as MediaTypeDetectionHelper
from ...dyn.frame.module_manager import ModuleManager as ModuleManager
from ...dyn.frame.office_frame_loader import OfficeFrameLoader as OfficeFrameLoader
from ...dyn.frame.popup_menu_controller import PopupMenuController as PopupMenuController
from ...dyn.frame.popup_menu_controller_factory import PopupMenuControllerFactory as PopupMenuControllerFactory
from ...dyn.frame.protocol_handler import ProtocolHandler as ProtocolHandler
from ...dyn.frame.session_listener import SessionListener as SessionListener
from ...dyn.frame.session_manager import SessionManager as SessionManager
from ...dyn.frame.settings import Settings as Settings
from ...dyn.frame.start_module import StartModule as StartModule
from ...dyn.frame.statusbar_controller import StatusbarController as StatusbarController
from ...dyn.frame.statusbar_controller_factory import StatusbarControllerFactory as StatusbarControllerFactory
from ...dyn.frame.synchronous_frame_loader import SynchronousFrameLoader as SynchronousFrameLoader
from ...dyn.frame.task import Task as Task
from ...dyn.frame.task_creator import TaskCreator as TaskCreator
from ...dyn.frame.template_access import TemplateAccess as TemplateAccess
from ...dyn.frame.termination_veto_exception import TerminationVetoException as TerminationVetoException
from ...dyn.frame.title_changed_event import TitleChangedEvent as TitleChangedEvent
from ...dyn.frame.toolbar_controller import ToolbarController as ToolbarController
from ...dyn.frame.toolbar_controller_factory import ToolbarControllerFactory as ToolbarControllerFactory
from ...dyn.frame.transient_documents_document_content_factory import TransientDocumentsDocumentContentFactory as TransientDocumentsDocumentContentFactory
from ...dyn.frame.ui_command_description import UICommandDescription as UICommandDescription
from ...dyn.frame.unknown_module_exception import UnknownModuleException as UnknownModuleException
from ...dyn.frame.untitled_numbers_const import UntitledNumbersConst as UntitledNumbersConst
from ...dyn.frame.untitled_numbers_const import UntitledNumbersConstEnum as UntitledNumbersConstEnum
from ...dyn.frame.window_arrange import WindowArrange as WindowArrange
from ...dyn.frame.window_arrange import WindowArrangeEnum as WindowArrangeEnum
from ...dyn.frame.x_app_dispatch_provider import XAppDispatchProvider as XAppDispatchProvider
from ...dyn.frame.x_border_resize_listener import XBorderResizeListener as XBorderResizeListener
from ...dyn.frame.x_browse_history_registry import XBrowseHistoryRegistry as XBrowseHistoryRegistry
from ...dyn.frame.x_component_loader import XComponentLoader as XComponentLoader
from ...dyn.frame.x_component_registry import XComponentRegistry as XComponentRegistry
from ...dyn.frame.x_config_manager import XConfigManager as XConfigManager
from ...dyn.frame.x_control_notification_listener import XControlNotificationListener as XControlNotificationListener
from ...dyn.frame.x_controller import XController as XController
from ...dyn.frame.x_controller2 import XController2 as XController2
from ...dyn.frame.x_controller_border import XControllerBorder as XControllerBorder
from ...dyn.frame.x_desktop import XDesktop as XDesktop
from ...dyn.frame.x_desktop2 import XDesktop2 as XDesktop2
from ...dyn.frame.x_desktop_task import XDesktopTask as XDesktopTask
from ...dyn.frame.x_dispatch import XDispatch as XDispatch
from ...dyn.frame.x_dispatch_helper import XDispatchHelper as XDispatchHelper
from ...dyn.frame.x_dispatch_information_provider import XDispatchInformationProvider as XDispatchInformationProvider
from ...dyn.frame.x_dispatch_provider import XDispatchProvider as XDispatchProvider
from ...dyn.frame.x_dispatch_provider_interception import XDispatchProviderInterception as XDispatchProviderInterception
from ...dyn.frame.x_dispatch_provider_interceptor import XDispatchProviderInterceptor as XDispatchProviderInterceptor
from ...dyn.frame.x_dispatch_recorder import XDispatchRecorder as XDispatchRecorder
from ...dyn.frame.x_dispatch_recorder_supplier import XDispatchRecorderSupplier as XDispatchRecorderSupplier
from ...dyn.frame.x_dispatch_result_listener import XDispatchResultListener as XDispatchResultListener
from ...dyn.frame.x_document_templates import XDocumentTemplates as XDocumentTemplates
from ...dyn.frame.x_extended_filter_detection import XExtendedFilterDetection as XExtendedFilterDetection
from ...dyn.frame.x_filter_detect import XFilterDetect as XFilterDetect
from ...dyn.frame.x_frame import XFrame as XFrame
from ...dyn.frame.x_frame2 import XFrame2 as XFrame2
from ...dyn.frame.x_frame_action_listener import XFrameActionListener as XFrameActionListener
from ...dyn.frame.x_frame_loader import XFrameLoader as XFrameLoader
from ...dyn.frame.x_frame_loader_query import XFrameLoaderQuery as XFrameLoaderQuery
from ...dyn.frame.x_frame_set_model import XFrameSetModel as XFrameSetModel
from ...dyn.frame.x_frames import XFrames as XFrames
from ...dyn.frame.x_frames_supplier import XFramesSupplier as XFramesSupplier
from ...dyn.frame.x_global_event_broadcaster import XGlobalEventBroadcaster as XGlobalEventBroadcaster
from ...dyn.frame.x_infobar_provider import XInfobarProvider as XInfobarProvider
from ...dyn.frame.x_interceptor_info import XInterceptorInfo as XInterceptorInfo
from ...dyn.frame.x_layout_manager import XLayoutManager as XLayoutManager
from ...dyn.frame.x_layout_manager2 import XLayoutManager2 as XLayoutManager2
from ...dyn.frame.x_layout_manager_event_broadcaster import XLayoutManagerEventBroadcaster as XLayoutManagerEventBroadcaster
from ...dyn.frame.x_layout_manager_listener import XLayoutManagerListener as XLayoutManagerListener
from ...dyn.frame.x_load_event_listener import XLoadEventListener as XLoadEventListener
from ...dyn.frame.x_loadable import XLoadable as XLoadable
from ...dyn.frame.x_loader_factory import XLoaderFactory as XLoaderFactory
from ...dyn.frame.x_menu_bar_acceptor import XMenuBarAcceptor as XMenuBarAcceptor
from ...dyn.frame.x_menu_bar_merging_acceptor import XMenuBarMergingAcceptor as XMenuBarMergingAcceptor
from ...dyn.frame.x_model import XModel as XModel
from ...dyn.frame.x_model2 import XModel2 as XModel2
from ...dyn.frame.x_model3 import XModel3 as XModel3
from ...dyn.frame.x_module import XModule as XModule
from ...dyn.frame.x_module_manager import XModuleManager as XModuleManager
from ...dyn.frame.x_module_manager2 import XModuleManager2 as XModuleManager2
from ...dyn.frame.x_notifying_dispatch import XNotifyingDispatch as XNotifyingDispatch
from ...dyn.frame.x_popup_menu_controller import XPopupMenuController as XPopupMenuController
from ...dyn.frame.x_recordable_dispatch import XRecordableDispatch as XRecordableDispatch
from ...dyn.frame.x_session_manager_client import XSessionManagerClient as XSessionManagerClient
from ...dyn.frame.x_session_manager_listener import XSessionManagerListener as XSessionManagerListener
from ...dyn.frame.x_session_manager_listener2 import XSessionManagerListener2 as XSessionManagerListener2
from ...dyn.frame.x_status_listener import XStatusListener as XStatusListener
from ...dyn.frame.x_statusbar_controller import XStatusbarController as XStatusbarController
from ...dyn.frame.x_storable import XStorable as XStorable
from ...dyn.frame.x_storable2 import XStorable2 as XStorable2
from ...dyn.frame.x_sub_toolbar_controller import XSubToolbarController as XSubToolbarController
from ...dyn.frame.x_synchronous_dispatch import XSynchronousDispatch as XSynchronousDispatch
from ...dyn.frame.x_synchronous_frame_loader import XSynchronousFrameLoader as XSynchronousFrameLoader
from ...dyn.frame.x_task import XTask as XTask
from ...dyn.frame.x_tasks_supplier import XTasksSupplier as XTasksSupplier
from ...dyn.frame.x_terminate_listener import XTerminateListener as XTerminateListener
from ...dyn.frame.x_terminate_listener2 import XTerminateListener2 as XTerminateListener2
from ...dyn.frame.x_title import XTitle as XTitle
from ...dyn.frame.x_title_change_broadcaster import XTitleChangeBroadcaster as XTitleChangeBroadcaster
from ...dyn.frame.x_title_change_listener import XTitleChangeListener as XTitleChangeListener
from ...dyn.frame.x_toolbar_controller import XToolbarController as XToolbarController
from ...dyn.frame.x_toolbar_controller_listener import XToolbarControllerListener as XToolbarControllerListener
from ...dyn.frame.x_transient_documents_document_content_factory import XTransientDocumentsDocumentContentFactory as XTransientDocumentsDocumentContentFactory
from ...dyn.frame.x_transient_documents_document_content_identifier_factory import XTransientDocumentsDocumentContentIdentifierFactory as XTransientDocumentsDocumentContentIdentifierFactory
from ...dyn.frame.xui_controller_factory import XUIControllerFactory as XUIControllerFactory
from ...dyn.frame.xui_controller_registration import XUIControllerRegistration as XUIControllerRegistration
from ...dyn.frame.x_untitled_numbers import XUntitledNumbers as XUntitledNumbers
from ...dyn.frame.x_url_list import XUrlList as XUrlList
from ...dyn.frame.x_window_arranger import XWindowArranger as XWindowArranger
from ...dyn.frame.the_auto_recovery import theAutoRecovery as theAutoRecovery
from ...dyn.frame.the_desktop import theDesktop as theDesktop
from ...dyn.frame.the_global_event_broadcaster import theGlobalEventBroadcaster as theGlobalEventBroadcaster
from ...dyn.frame.the_popup_menu_controller_factory import thePopupMenuControllerFactory as thePopupMenuControllerFactory
from ...dyn.frame.the_statusbar_controller_factory import theStatusbarControllerFactory as theStatusbarControllerFactory
from ...dyn.frame.the_toolbar_controller_factory import theToolbarControllerFactory as theToolbarControllerFactory
from ...dyn.frame.the_ui_command_description import theUICommandDescription as theUICommandDescription
