# coding: utf-8
#
# Copyright 2022 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Interface Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.3
# Namespace: com.sun.star.reflection
from abc import abstractmethod
from ..uno.x_interface import XInterface as XInterface_8f010a43

class XIdlArray(XInterface_8f010a43):
    """
    Reflects an IDL sequence and provides dynamic access to instances of that sequence.
    
    This interface supports widening conversion when getting or setting elements.

    See Also:
        `API XIdlArray <https://api.libreoffice.org/docs/idl/ref/interfacecom_1_1sun_1_1star_1_1reflection_1_1XIdlArray.html>`_
    """
    __ooo_ns__: str = 'com.sun.star.reflection'
    __ooo_full_ns__: str = 'com.sun.star.reflection.XIdlArray'
    __ooo_type_name__: str = 'interface'
    __pyunointerface__: str = 'com.sun.star.reflection.XIdlArray'

    @abstractmethod
    def get(self, aArray: object, nIndex: int) -> object:
        """
        Returns element at given index.

        Raises:
            com.sun.star.lang.IllegalArgumentException: ``IllegalArgumentException``
            com.sun.star.lang.ArrayIndexOutOfBoundsException: ``ArrayIndexOutOfBoundsException``
        """
    @abstractmethod
    def getLen(self, array: object) -> int:
        """
        Returns the length of the given sequence.

        Raises:
            com.sun.star.lang.IllegalArgumentException: ``IllegalArgumentException``
        """
    @abstractmethod
    def realloc(self, array: object, length: int) -> None:
        """
        Reallocates the length of the sequence instance.

        Raises:
            com.sun.star.lang.IllegalArgumentException: ``IllegalArgumentException``
        """
    @abstractmethod
    def set(self, aArray: object, nIndex: int, aNewValue: object) -> None:
        """
        Sets a new value at given index.

        Raises:
            com.sun.star.lang.IllegalArgumentException: ``IllegalArgumentException``
            com.sun.star.lang.ArrayIndexOutOfBoundsException: ``ArrayIndexOutOfBoundsException``
        """

__all__ = ['XIdlArray']

