# coding: utf-8
#
# Copyright 2022 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Const Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.3
# Namespace: com.sun.star.security
from enum import IntFlag
from typing import TYPE_CHECKING
from ooo.oenv.env_const import UNO_ENVIRONMENT, UNO_RUNTIME
_DYNAMIC = False
if (not TYPE_CHECKING) and UNO_RUNTIME and UNO_ENVIRONMENT:
    _DYNAMIC = True

if not TYPE_CHECKING and _DYNAMIC:
    from com.sun.star.security import KeyUsage as KeyUsage
    if hasattr(KeyUsage, '_constants') and isinstance(KeyUsage._constants, dict):
        KeyUsage._constants['__ooo_ns__'] = 'com.sun.star.security'
        KeyUsage._constants['__ooo_full_ns__'] = 'com.sun.star.security.KeyUsage'
        KeyUsage._constants['__ooo_type_name__'] = 'const'
    def build_enum():
        global KeyUsageEnum
        ls = [f for f in dir(KeyUsage) if not callable(getattr(KeyUsage, f)) and not f.startswith('__')]
        _dict = {}
        for name in ls:
            _dict[name] = getattr(KeyUsage, name)
        KeyUsageEnum = IntFlag('KeyUsageEnum', _dict)
    build_enum()
else:
    from ...lo.security.key_usage import KeyUsage as KeyUsage

    class KeyUsageEnum(IntFlag):
        """
        Enum of Const Class KeyUsage

        """
        DIGITAL_SIGNATURE = KeyUsage.DIGITAL_SIGNATURE
        NON_REPUDIATION = KeyUsage.NON_REPUDIATION
        KEY_ENCIPHERMENT = KeyUsage.KEY_ENCIPHERMENT
        DATA_ENCIPHERMENT = KeyUsage.DATA_ENCIPHERMENT
        KEY_AGREEMENT = KeyUsage.KEY_AGREEMENT
        KEY_CERT_SIGN = KeyUsage.KEY_CERT_SIGN
        CRL_SIGN = KeyUsage.CRL_SIGN

__all__ = ['KeyUsage', 'KeyUsageEnum']
