# coding: utf-8
#
# Copyright 2022 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Service Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.3
# Namespace: com.sun.star.inspection
import typing
from abc import abstractmethod
from .x_string_representation import XStringRepresentation as XStringRepresentation_939311e6
if typing.TYPE_CHECKING:
    from ..script.x_type_converter import XTypeConverter as XTypeConverter_e48b0d4f

class StringRepresentation(XStringRepresentation_939311e6):
    """
    Service Class


    See Also:
        `API StringRepresentation <https://api.libreoffice.org/docs/idl/ref/servicecom_1_1sun_1_1star_1_1inspection_1_1StringRepresentation.html>`_
    """
    __ooo_ns__: str = 'com.sun.star.inspection'
    __ooo_full_ns__: str = 'com.sun.star.inspection.StringRepresentation'
    __ooo_type_name__: str = 'service'

    @abstractmethod
    def create(self, TypeConverter: 'XTypeConverter_e48b0d4f') -> None:
        """

        Raises:
            com.sun.star.lang.IllegalArgumentException: ``IllegalArgumentException``
        """
    @abstractmethod
    def createConstant(self, TypeConverter: 'XTypeConverter_e48b0d4f', Constant: str, Values: 'typing.Tuple[str, ...]') -> None:
        """

        Raises:
            com.sun.star.lang.IllegalArgumentException: ``IllegalArgumentException``
        """


__all__ = ['StringRepresentation']

